package MyData::Blog;
use strict; 
use base qw/MyData::Base/;
use DateTime;
use DateTime::Format::MySQL;

__PACKAGE__->table('blog');
__PACKAGE__->create_table(q{
  `id` int(10) unsigned NOT NULL auto_increment,
  `title` varchar(255) NOT NULL,
  `description` varchar(255) NOT NULL,
  `created_at` datetime NOT NULL,
  `updated_at` datetime NOT NULL,
  PRIMARY KEY  (`id`)
});
__PACKAGE__->set_up_table;

__PACKAGE__->has_a(created_at => 'DateTime',
    inflate => sub {
        DateTime::Format::MySQL->parse_datetime( shift );
    },
);
__PACKAGE__->add_trigger(
    before_create => sub {
        my $self = shift;
        my $now = DateTime->now( time_zone => "local")->strftime('%Y-%m-%d %H:%M:%S');
        $self->_attribute_set(created_at => $now);
        $self->_attribute_set(updated_at => $now);
    },
);

__PACKAGE__->add_trigger(
    before_update => sub {
        my $self = shift;
        my $now = DateTime->now( time_zone => "local")->strftime('%Y-%m-%d %H:%M:%S');
        $self->updated_at($now); 
    },
);

1;
__END__
